# jTWA.visualization

``jTWA.visualization`` comprises all plotting functionality.
Visualizations strongly depend on the physical scenario of interest and therefore no one-size-fits-all solution is possible.
The provided code is therefore to be understood as a first step to simplify building more specialized visualizations.

```{eval-rst}
.. autofunction:: jTWA.visualization.create_visuals
```

```{eval-rst}
.. autofunction:: jTWA.visualization.plot_spin_obs
```

```{eval-rst}
.. autofunction:: jTWA.visualization.plot_correlation_matrices
```

```{eval-rst}
.. autofunction:: jTWA.visualization.animate
```

```{eval-rst}
.. autofunction:: jTWA.visualization.plot_deviations
```